summaryrefslogtreecommitdiffstats
path: root/editor/libeditor/HTMLEditor.h
diff options
context:
space:
mode:
authorDaniel Baumann <daniel.baumann@progress-linux.org>2024-06-12 05:35:37 +0000
committerDaniel Baumann <daniel.baumann@progress-linux.org>2024-06-12 05:35:37 +0000
commita90a5cba08fdf6c0ceb95101c275108a152a3aed (patch)
tree532507288f3defd7f4dcf1af49698bcb76034855 /editor/libeditor/HTMLEditor.h
parentAdding debian version 126.0.1-1. (diff)
downloadfirefox-a90a5cba08fdf6c0ceb95101c275108a152a3aed.tar.xz
firefox-a90a5cba08fdf6c0ceb95101c275108a152a3aed.zip
Merging upstream version 127.0.
Signed-off-by: Daniel Baumann <daniel.baumann@progress-linux.org>
Diffstat (limited to 'editor/libeditor/HTMLEditor.h')
-rw-r--r--editor/libeditor/HTMLEditor.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/editor/libeditor/HTMLEditor.h b/editor/libeditor/HTMLEditor.h
index 2a31ead29d..e56ae0fe33 100644
--- a/editor/libeditor/HTMLEditor.h
+++ b/editor/libeditor/HTMLEditor.h
@@ -1333,7 +1333,8 @@ class HTMLEditor final : public EditorBase,
* @param aHTMLEditor The HTML editor.
* @param aSrcElement The element which have the attribute.
* @param aDestElement The element which will have the attribute.
* @param aAttr [in] The attribute which will be copied.
* @param aValue [in/out] The attribute value which will be copied.
* Once updated, the new value is used.
* @return true if the attribute should be copied, otherwise,
@@ -1341,7 +1342,7 @@ class HTMLEditor final : public EditorBase,
*/
using AttributeFilter = std::function<bool(
HTMLEditor& aHTMLEditor, Element& aSrcElement, Element& aDestElement,
- const dom::Attr& aAttr, nsString& aValue)>;
+ int32_t aNamespaceID, const nsAtom& aAttrName, nsString& aValue)>;
static AttributeFilter CopyAllAttributes;
static AttributeFilter CopyAllAttributesExceptId;
static AttributeFilter CopyAllAttributesExceptDir;
@@ -1333,7 +1333,8 @@ class HTMLEditor final : public EditorBase,
* @param aSrcElement The element which have the attribute.
* @param aDestElement The element which will have the attribute.
- * @param aAttr [in] The attribute which will be copied.
+ * @param aNamespaceID [in] The namespace ID of aAttrName.
+ * @param aAttrName [in] The attribute name which will be copied.
* @param aValue [in/out] The attribute value which will be copied.
* Once updated, the new value is used.